==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/FlockerVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface FlockerVolumeSourceFluent<A extends FlockerVolumeSourceFluent<A>> extends Fluent<A> {


    public String getDatasetName();
    public A withDatasetName(String datasetName);
    public Boolean hasDatasetName();
    public A withNewDatasetName(StringBuilder arg1);
    public A withNewDatasetName(int[] arg1,int arg2,int arg3);
    public A withNewDatasetName(char[] arg1);
    public A withNewDatasetName(StringBuffer arg1);
    public A withNewDatasetName(byte[] arg1,int arg2);
    public A withNewDatasetName(byte[] arg1);
    public A withNewDatasetName(char[] arg1,int arg2,int arg3);
    public A withNewDatasetName(byte[] arg1,int arg2,int arg3);
    public A withNewDatasetName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatasetName(String arg1);
    public String getDatasetUUID();
    public A withDatasetUUID(String datasetUUID);
    public Boolean hasDatasetUUID();
    public A withNewDatasetUUID(StringBuilder arg1);
    public A withNewDatasetUUID(int[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(char[] arg1);
    public A withNewDatasetUUID(StringBuffer arg1);
    public A withNewDatasetUUID(byte[] arg1,int arg2);
    public A withNewDatasetUUID(byte[] arg1);
    public A withNewDatasetUUID(char[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(byte[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatasetUUID(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/FlockerVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface FlockerVolumeSourceFluent<A extends FlockerVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getDatasetName();
    public A withDatasetName(String datasetName);
    public Boolean hasDatasetName();
    public A withNewDatasetName(StringBuilder arg1);
    public A withNewDatasetName(int[] arg1,int arg2,int arg3);
    public A withNewDatasetName(char[] arg1);
    public A withNewDatasetName(StringBuffer arg1);
    public A withNewDatasetName(byte[] arg1,int arg2);
    public A withNewDatasetName(byte[] arg1);
    public A withNewDatasetName(char[] arg1,int arg2,int arg3);
    public A withNewDatasetName(byte[] arg1,int arg2,int arg3);
    public A withNewDatasetName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatasetName(String arg1);
    public String getDatasetUUID();
    public A withDatasetUUID(String datasetUUID);
    public Boolean hasDatasetUUID();
    public A withNewDatasetUUID(StringBuilder arg1);
    public A withNewDatasetUUID(int[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(char[] arg1);
    public A withNewDatasetUUID(StringBuffer arg1);
    public A withNewDatasetUUID(byte[] arg1,int arg2);
    public A withNewDatasetUUID(byte[] arg1);
    public A withNewDatasetUUID(char[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(byte[] arg1,int arg2,int arg3);
    public A withNewDatasetUUID(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDatasetUUID(String arg1);
}
